summaryrefslogtreecommitdiff
path: root/src/mapblock.cpp
diff options
context:
space:
mode:
authordarkrose <lisa@ltmnet.com>2012-07-17 23:00:04 +1000
committerPerttu Ahola <celeron55@gmail.com>2012-07-23 08:18:37 +0300
commitcd6becd442a50a6e2f7129108e1c2c495f885764 (patch)
tree9f013b53ff4ec7d4df6ee26769e397f3defee268 /src/mapblock.cpp
parent829f262c7954c4eb82eff3931d065fce8bc7809e (diff)
downloadminetest-cd6becd442a50a6e2f7129108e1c2c495f885764.tar.gz
minetest-cd6becd442a50a6e2f7129108e1c2c495f885764.tar.bz2
minetest-cd6becd442a50a6e2f7129108e1c2c495f885764.zip
Implement node timers
Diffstat (limited to 'src/mapblock.cpp')
-rw-r--r--src/mapblock.cpp14
1 files changed, 7 insertions, 7 deletions
diff --git a/src/mapblock.cpp b/src/mapblock.cpp
index efe628a4e..62c670fd3 100644
--- a/src/mapblock.cpp
+++ b/src/mapblock.cpp
@@ -621,9 +621,9 @@ void MapBlock::serialize(std::ostream &os, u8 version, bool disk)
// (this field should have not been added)
if(version == 23)
writeU8(os, 0);
- // Node timers (uncomment when node timers are taken into use)
- /*if(version >= 24)
- m_node_timers.serialize(os);*/
+ // Node timers are in version 24
+ if(version >= 24)
+ m_node_timers.serialize(os);
// Static objects
m_static_objects.serialize(os);
@@ -703,15 +703,15 @@ void MapBlock::deSerialize(std::istream &is, u8 version, bool disk)
if(disk)
{
// Node timers
- if(version == 23)
+ if(version == 23){
// Read unused zero
readU8(is);
- // Uncomment when node timers are taken into use
- /*else if(version >= 24){
+ }
+ else if(version >= 24){
TRACESTREAM(<<"MapBlock::deSerialize "<<PP(getPos())
<<": Node timers"<<std::endl);
m_node_timers.deSerialize(is);
- }*/
+ }
// Static objects
TRACESTREAM(<<"MapBlock::deSerialize "<<PP(getPos())